@@ -3,8 +3,8 @@ use Modern::Perl;
 use YAML::Any;
 use Moose::Util qw( with_traits );
 use lib '../lib';
-use Data::Walk::Extracted v0.05;
-use Data::Walk::Print v0.05;#Only required if explicitly called
+use Data::Walk::Extracted v0.007;
+use Data::Walk::Print v0.007;
 
 $| = 1;
 
@@ -49,7 +49,7 @@ my $AT_ST = $newclass->new(
         match_highlighting => 1,#This is the default
         sort_HASH => 1,#To force order for demo purposes
 );
-$AT_ST->walk_the_data(
-    primary_ref     =>  $firstref,
-    secondary_ref   =>  $secondref,
+$AT_ST->print_data(
+    print_ref     =>  $firstref,
+    match_ref   =>  $secondref,
 );
\ No newline at end of file
